package com.winhc.bigdata.spark.ng.utils

import com.winhc.bigdata.spark.utils.{Alias, ElasticSearchIndexUtils, LoggingUtils, SparkUtils}
import org.apache.spark.sql.SparkSession

import scala.annotation.meta.getter
import scala.collection.mutable

/**
 * @author: XuJiakai
 * @date: 2021/4/29 16:31
 */

case class SwitchSummaryIndex(s: SparkSession
                             ) extends LoggingUtils {
  @(transient@getter) val spark: SparkSession = s

  private lazy val es = ElasticSearchIndexUtils()

  private val company_summary_alias = "company_summary"
  private val person_summary_alias = "company_summary_person"

  def switch(ds: String): Unit = {
    val company_summary = "out_es_summary_v" + ds
    val person_summary = "out_es_summary_person_v" + ds

    val size = es.catIndices().filter(a => a.equals(company_summary) || a.equals(person_summary)).size
    if (size != 2) {
      throw new RuntimeException("target indices is not found !")
    }

    val ali: Seq[Alias] = es.catAliases()
      .filter(a => a.alias.equals(company_summary_alias) || a.alias.equals(person_summary_alias))

    val add_alias = Seq(
      Alias(alias = company_summary_alias, index = company_summary)
      , Alias(alias = person_summary_alias, index = person_summary)
    )

    import com.winhc.bigdata.spark.implicits.CaseClass2JsonHelper.CaseClass2JsonEnhancer
    println(
      s"""
         |remove alias: ${ali.toJson()}
         |add alias: ${add_alias.toJson()}
         |""".stripMargin)

    es.updateAliases(add_alias,ali)
  }
}


object SwitchSummaryIndex {
  def main(args: Array[String]): Unit = {
    val Array(ds) = args
    val project = "winhc_ng"
    val config = mutable.Map(
      "spark.hadoop.odps.project.name" -> project,
      "spark.debug.maxToStringFields" -> "200",
      "spark.hadoop.odps.spark.local.partition.amt" -> "100"
    )
    val spark = SparkUtils.InitEnv(this.getClass.getSimpleName, config)

    SwitchSummaryIndex(spark).switch(ds)

    spark.stop()
  }
}
